@@ -1,5 +1,5 @@
 /* Environment modification functions for GNU Pies.
-   Copyright (C) 2019-2020 Sergey Poznyakoff
+   Copyright (C) 2019-2021 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -71,6 +71,7 @@ environ_free (environ_t *env)
   for (i = 0; i < env->env_count; i++)
     free (env->env_base[i]);
   free (env->env_base);
+  free (env);
 }
 
 static ssize_t
@@ -502,4 +503,40 @@ envop_free (struct envop_entry *op)
       op = next;
     }
 }
-      
+
+int
+envop_cmp (struct envop_entry *a, struct envop_entry *b)
+{
+  while (a)
+    {
+      if (!b)
+	return 1;
+      if (a->code != b->code)
+	return 1;
+      switch (a->code)
+	{
+	case envop_clear:
+	  break;
+	  
+	case envop_keep:
+	case envop_set:
+	case envop_unset:
+	  if (strcmp (a->name, b->name))
+	    return 1;
+
+	  if (!a->value)
+	    {
+	      if (b->value)
+		return 1;
+	    }
+	  else if (!b->value || strcmp (a->value, b->value))
+	    return 1;
+	  break;
+	}
+      a = a->next;
+      b = b->next;
+    }
+  if (b)
+    return 1;
+  return 0;
+}
