@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2015-2020 Sergey Poznyakoff
+   Copyright (C) 2015-2021 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -56,13 +56,13 @@ pp_command_line (void)
 {
   char *ret;
   
-  if (!DEFAULT_PREPROCESSOR)
+  if (!grecs_preprocessor)
     return NULL;
   
   if (!pp_cmd)
     {
       pp_cmd = grecs_txtacc_create ();
-      grecs_txtacc_grow_string (pp_cmd, DEFAULT_PREPROCESSOR);
+      grecs_txtacc_grow_string (pp_cmd, grecs_preprocessor);
     }
   grecs_txtacc_grow_char (pp_cmd, 0);
   ret = grecs_txtacc_finish (pp_cmd, 1);
