@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies
-   Copyright (C) 2009-2019 Sergey Poznyakoff
+   Copyright (C) 2009-2021 Sergey Poznyakoff
   
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -183,7 +183,7 @@ _parse_sockaddr (struct acl_entry *entry, const grecs_value_t *value)
   struct pies_sockaddr *sptr;
   const char *string;
 
-  if (assert_grecs_value_type (&entry->locus, value, GRECS_TYPE_STRING))
+  if (grecs_assert_value_type (value, GRECS_TYPE_STRING, &entry->locus))
     return 1;
 
   string = value->v.string;
@@ -431,7 +431,7 @@ _parse_group (struct acl_entry *entry, size_t argc, grecs_value_t **argv)
 static int
 _parse_acl (struct acl_entry *entry, size_t argc, grecs_value_t **argv)
 {
-  if (assert_grecs_value_type (&entry->locus, argv[0], GRECS_TYPE_STRING))
+  if (grecs_assert_value_type (argv[0], GRECS_TYPE_STRING, &entry->locus))
     return 1;
   else if (_parse_token (entry, argv[0]) == 0)
     return _parse_sub_acl (entry, argc - 1, argv + 1);
@@ -570,7 +570,7 @@ _acl_common_section_parser (enum grecs_callback_command cmd,
       break;
       
     case grecs_callback_set_value:
-      if (assert_grecs_value_type (&value->locus, value, GRECS_TYPE_STRING))
+      if (grecs_assert_value_type (value, GRECS_TYPE_STRING, &value->locus))
 	return 0;
       acl = pies_acl_lookup (value->v.string);
       if (!acl)
@@ -592,11 +592,11 @@ _acl_common_section_parser (enum grecs_callback_command cmd,
 
 int
 acl_section_parser (enum grecs_callback_command cmd,
-		    grecs_locus_t *locus,
-		    void *varptr,
-		    grecs_value_t *value,
-		    void *cb_data)
+		    grecs_node_t *node,
+		    void *varptr, void *cb_data)
 {
+  grecs_locus_t *locus = &node->locus;
+  grecs_value_t *value = node->v.value;
   int rc = _acl_common_section_parser (cmd, locus, value, varptr,
 				       ACL_TAG_NONE);
   if (rc == 0)
@@ -606,22 +606,22 @@ acl_section_parser (enum grecs_callback_command cmd,
 
 int
 defacl_section_parser (enum grecs_callback_command cmd,
-		       grecs_locus_t *locus,
-		       void *varptr,
-		       grecs_value_t *value,
-		       void *cb_data)
+		       grecs_node_t *node,
+		       void *varptr, void *cb_data)
 {
+  grecs_locus_t *locus = &node->locus;
+  grecs_value_t *value = node->v.value;
   return _acl_common_section_parser (cmd, locus, value, cb_data,
 				     ACL_TAG_REQUIRED);
 }
 
 static int
 allow_cb (enum grecs_callback_command cmd,
-	  grecs_locus_t *locus,
-	  void *varptr,
-	  grecs_value_t *value,
-	  void *cb_data)
+	  grecs_node_t *node,
+	  void *varptr, void *cb_data)
 {
+  grecs_locus_t *locus = &node->locus;
+  grecs_value_t *value = node->v.value;
   pies_acl_t acl = varptr;
 
   if (cmd != grecs_callback_set_value)
@@ -635,11 +635,11 @@ allow_cb (enum grecs_callback_command cmd,
 
 static int
 deny_cb (enum grecs_callback_command cmd,
-	 grecs_locus_t *locus,
-	 void *varptr,
-	 grecs_value_t *value,
-	 void *cb_data)
+	 grecs_node_t *node,
+	 void *varptr, void *cb_data)
 {
+  grecs_locus_t *locus = &node->locus;
+  grecs_value_t *value = node->v.value;
   pies_acl_t acl = varptr;
   if (cmd != grecs_callback_set_value)
     {
